                            Medium multiply


A small demo library


Installation

    pip install helloworlds


Get started

    greetings = Hello()

    # Call the  method
    greetings.sayhello()
        